@@ -23,7 +23,7 @@ import re
 import random
 import subprocess
 import socket
-from functools import wraps
+from functools import wraps, partial
 from contextlib import contextmanager
 from subprocess import check_call
 if sys.version_info[:2] < (3, 2):
@@ -210,6 +210,28 @@ def patch_libudev(funcname):
         yield func
 
 
+@contextmanager
+def patch_libudev_list(items, list_func):
+    item_list = iter(items)
+
+    def name(entry):
+        if entry:
+            return entry
+        else:
+            pytest.fail('empty entry!')
+
+    get_next = 'udev_list_entry_get_next'
+    get_name = 'udev_list_entry_get_name'
+    with pytest.nested(pytest.patch_libudev(get_next),
+                       pytest.patch_libudev(get_name),
+                       pytest.patch_libudev(list_func)) as (get_next, get_name,
+                                                           list_func):
+        list_func.return_value = next(item_list)
+        get_name.side_effect = name
+        get_next.side_effect = lambda e: next(item_list, None)
+        yield list_func
+
+
 def _need_privileges(func):
     @wraps(func)
     def wrapped(*args):
@@ -227,6 +249,7 @@ def load_dummy():
     """
     check_call(['sudo', 'modprobe', 'dummy'])
 
+
 @_need_privileges
 def unload_dummy():
     """
@@ -248,9 +271,9 @@ def is_unicode_string(value):
     return isinstance(value, unicode_type)
 
 
-def check_udev_version(version_spec):
+def need_udev_version(version_spec):
     """
-    Decorator to check the udev version.
+    Decorator to check the udev version before a test is run.
 
     ``version_spec`` is a string containing a comparison operator and the right
     hand sight operand of this comparison, like ``'>= 165'``.  The left hand
@@ -270,7 +293,8 @@ def check_udev_version(version_spec):
 def pytest_namespace():
     return dict((func.__name__, func) for func in
                 (get_device_sample, patch_libudev, load_dummy, nested,
-                 unload_dummy, is_unicode_string, check_udev_version))
+                 unload_dummy, is_unicode_string, need_udev_version,
+                 patch_libudev_list))
 
 
 def pytest_addoption(parser):
@@ -292,6 +316,7 @@ def pytest_addoption(parser):
                      'code, be sure to have proper privileges before '
                      'enabling this option!', default=False)
 
+
 def pytest_configure(config):
     # these are volatile, frequently changing properties and attributes,
     # which lead to bogus failures during tests, and therefore they are
@@ -324,6 +349,7 @@ def pytest_funcarg__context(request):
     """
     return request.cached_setup(setup=pyudev.Context, scope='session')
 
+
 def pytest_funcarg__device_path(request):
     """
     Return a device path as string.
@@ -332,6 +358,7 @@ def pytest_funcarg__device_path(request):
     """
     return request.param
 
+
 def pytest_funcarg__all_properties(request):
     """
     Get all properties from the exported database (as returned by the
@@ -341,6 +368,7 @@ def pytest_funcarg__all_properties(request):
     device_path = request.getfuncargvalue('device_path')
     return dict(request.getfuncargvalue('database')[device_path])
 
+
 def pytest_funcarg__properties(request):
     """
     Same as the ``all_properties`` funcarg, but with the special ``DEVNAME``
@@ -350,6 +378,7 @@ def pytest_funcarg__properties(request):
     properties.pop('DEVNAME', None)
     return properties
 
+
 def pytest_funcarg__attributes(request):
     """
     Return a dictionary of all attributes for the device pointed to by the
@@ -359,6 +388,7 @@ def pytest_funcarg__attributes(request):
     return _get_device_attributes(
         device_path, request.config.attributes_blacklist)
 
+
 def pytest_funcarg__device_node(request):
     """
     Return the name of the device node for the device pointed to by the
@@ -367,6 +397,7 @@ def pytest_funcarg__device_node(request):
     device_path = request.getfuncargvalue('device_path')
     return _query_device(device_path, 'name')
 
+
 def pytest_funcarg__device_links(request):
     """
     Return a list of symlink to the device node (``device_node`` funcarg)
@@ -375,6 +406,7 @@ def pytest_funcarg__device_links(request):
     device_path = request.getfuncargvalue('device_path')
     return _query_device(device_path, 'symlink')
 
+
 def pytest_funcarg__sys_path(request):
     """
     Return the sys_path including the sysfs mountpoint for the device path
@@ -384,6 +416,7 @@ def pytest_funcarg__sys_path(request):
     device_path = request.getfuncargvalue('device_path')
     return context.sys_path + device_path
 
+
 def pytest_funcarg__device(request):
     """
     Create and return a :class:`pyudev.Device` object for the sys_path
@@ -394,6 +427,7 @@ def pytest_funcarg__device(request):
     context = request.getfuncargvalue('context')
     return pyudev.Device.from_sys_path(context, sys_path)
 
+
 def pytest_funcarg__platform_device(request):
     """
     Return the platform device at ``/sys/devices/platform``.  This device
@@ -403,6 +437,7 @@ def pytest_funcarg__platform_device(request):
     context = request.getfuncargvalue('context')
     return pyudev.Device.from_sys_path(context, '/sys/devices/platform')
 
+
 def pytest_funcarg__socket_path(request):
     """
     Return a socket path for :meth:`pyudev.Monitor.from_socket`.  The path
@@ -411,16 +446,17 @@ def pytest_funcarg__socket_path(request):
     tmpdir = request.getfuncargvalue('tmpdir')
     return tmpdir.join('monitor-socket')
 
+
 def pytest_funcarg__monitor(request):
     """
     Return a netlink monitor for udev source.
     """
     return pyudev.Monitor.from_netlink(request.getfuncargvalue('context'))
 
+
 def pytest_funcarg__fake_monitor(request):
     """
     Return a FakeMonitor, which emits the platform device as returned by
     the ``platform_device`` funcarg on all triggered actions.
     """
     return FakeMonitor(request.getfuncargvalue('platform_device'))
-
