@@ -55,25 +55,25 @@ def test_match_property_bool(context):
     assert all(d.asbool('ID_INPUT_KEY') for d in devices)
 
 
-@pytest.check_udev_version('>= 154')
+@pytest.need_udev_version('>= 154')
 def test_match_tags_mock(context):
     add_match_tag = 'udev_enumerate_add_match_tag'
     enumerator = context.list_devices()
     with pytest.patch_libudev(add_match_tag) as add_match_tag:
         retval = enumerator.match_tag('spam')
         assert retval is enumerator
-        add_match_tag.assert_called_with(enumerator._enumerator, b'spam')
+        add_match_tag.assert_called_with(enumerator, b'spam')
         args, _ = add_match_tag.call_args
         assert isinstance(args[1], bytes)
 
 
 @pytest.mark.xfail(reason='Not implemented')
-@pytest.check_udev_version('>= 154')
+@pytest.need_udev_version('>= 154')
 def test_match_tags():
     raise NotImplementedError()
 
 
-@pytest.check_udev_version('>= 165')
+@pytest.need_udev_version('>= 165')
 def test_match_is_initialized(context):
     match_is_initialized = 'udev_enumerate_add_match_is_initialized'
     with pytest.patch_libudev(match_is_initialized) as match_is_initialized:
