@@ -34,7 +34,9 @@ UDEV_ADDITIONS = {
           'udev_monitor_filter_add_match_tag'],
     165: ['udev_device_get_is_initialized',
           'udev_device_get_usec_since_initialized',
-          'udev_enumerate_add_match_is_initialized']
+          'udev_enumerate_add_match_is_initialized'],
+    167: ['udev_get_run_path',
+          'udev_device_get_sysattr_list_entry'],
     }
 
 
@@ -57,20 +59,23 @@ def pytest_funcarg__signature(request):
     namespace, name = request.param
     return binding.SIGNATURES[namespace][name]
 
+
 def pytest_funcarg__argtypes(request):
     argtypes, _ = request.getfuncargvalue('signature')
     return argtypes
 
+
 def pytest_funcarg__restype(request):
     _, restype = request.getfuncargvalue('signature')
     return restype
 
+
 def pytest_funcarg__errcheck(request):
     funcname = request.getfuncargvalue('funcname')
     return binding.ERROR_CHECKERS.get(funcname)
 
 
-@pytest.check_udev_version('>= 165')
+@pytest.need_udev_version('>= {0}'.format(max(UDEV_ADDITIONS)))
 def test_presence(funcname):
     assert hasattr(libudev, funcname)
 
